==> PPDF_1_2.zip: PubMedPDF/include/db.php <==
<?php
#-----------------------------------------------------------
# DatabaseϿ
#
# ǡ, 桼̾
#
# ǡܺ١ȴƤƤܤäƤOK
# array[
# id, j(journal), y(year), v(vol), p(page), ab(abstract), t(title), a(author),
# t_jp(title_jp), j_jp(journal_jp), a_jp(author_jp),
# ]
#
# : id number
#------------------------------------------------------------

function DB($data, $user){
		include "conn.php";

		$day = getdate();
		$date = $day["year"] ."-". $day["mon"] ."-". $day["mday"];

		$data[a] = str_replace("'","\'",$data[a]);
		$data[t] = str_replace("'","\'",$data[t]);
		$data[ab] = str_replace("'","\'",$data[ab]);
		$data[j] = str_replace("'","\'",$data[j]);
		
		# Journal
		$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) == 0){
			$sql = "INSERT INTO ".$T_JOURNAL." VALUES('','".$data[j]."','','','0','','','','')";
			$res = mysql_query($sql, $conn);
		}
		$sql = "SELECT id FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$jid = $row["id"];

		# Author
		$Author = explode(", ",$data[a]);
		$aid = "";
		for($i=0; $i<count($Author); $i++){
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) == 0){
				$sql = "INSERT INTO ".$T_AUTHOR." VALUES('','".$Author[$i]."','','')";
				$res = mysql_query($sql, $conn);
			}
			$sql = "SELECT id FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$aid.="[".$row["id"]."],";
		}

		# Pmid	
		$sql = "INSERT INTO ".$T_ID." VALUES(";
		$sql.= "'','".$data[id]."','".$jid."','".$data[y]."','".$data[v]."','".$data[p]."',";
		$sql.= "'".$aid."','".$data[t]."','".$data[ab]."','".$user."','".$date."',";
		$sql.= "'','','".$data[t_jp]."','".$data[a_jp]."','".$data[c_t1].
			   "','','','','','')";
		$res = mysql_query($sql, $conn);

		return mysql_insert_id($conn);
}


function MOD_DB($id, $data){
		
		include "conn.php";

		$data[a] = str_replace("'","\'",$data[a]);
		$data[t] = str_replace("'","\'",$data[t]);
		$data[ab] = str_replace("'","\'",$data[ab]);

		# Journal
		$sql = "SELECT id FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$jid = $row["id"];

		# Author
		$Author = explode(", ",$data[a]);
		$aid = "";
		for($i=0; $i<count($Author); $i++){
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) == 0){
				$sql = "INSERT INTO ".$T_AUTHOR." VALUES('','".$Author[$i]."','','')";
				$res = mysql_query($sql, $conn);
			}
			$sql = "SELECT id FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$aid.="[".$row["id"]."],";
		}
		
		# Pmid
		$sql = "UPDATE  ".$T_ID." SET ";
		$sql.= "Journal='".$jid."', Year='".$data[y]."', Volume='".$data[v]."',";
		$sql.= "Page='".$data[p]."', Author='".$aid."', Title='".$data[t]."',";
		$sql.= "Abstract='".$data[ab]."', Title_JP='".$data[t_jp].
			   "', Author_JP='".$data[a_jp]."', Custom_t1='".$data[c_t1]."' ";
		$sql.="WHERE id=$id";
		$res = mysql_query($sql, $conn);

		return mysql_insert_id($conn);
}


#-----------------------------------------------------------
# JournalDatabaseϿ, ѹ
#
# ǡ
#
# ǡܺ١ȴƤƤܤäƤOK
# array[
# j(journal), j_jp(journal_jp), j_url(journal_url), bk(book flg), act(active flg)
# e(editor), pub(publisher)
# ]
#
# : id number
#------------------------------------------------------------

function REG_JOURNAL($data){
	include "conn.php";

	$data[j] = str_replace("'","\'",$data[j]);
	$sql = "INSERT INTO ".$T_JOURNAL." VALUES(";
	$sql.= "'','".$data[j]."','".$data[j_jp]."','".$data[j_url]."','".$data[bk]."','".$data[e]."','".$data[pub]."','','')";
	$res = mysql_query($sql, $conn);
	return mysql_insert_id($conn);		
}

function EDIT_JOURNAL($data){
	include "conn.php";

	$data[j] = str_replace("'","\'",$data[j]);
	$sql = "UPDATE ".$T_JOURNAL." SET Journal='".$data[j]."',Journal_JP='".$data[j_jp]."',";
	$sql.="URL='".$data[j_url]."',Book='".$data[bk]."',Editor='".$data[e]."',";
	$sql.="Publisher='".$data[pub]."'";
	$sql.=" WHERE id='".$data[id]."'";
	$res = mysql_query($sql, $conn);
	return mysql_insert_id($conn);		
}
?>

==> PPDF_1_3_1.zip: PubMedPDF/include/db.php <==
<?php
#-----------------------------------------------------------
# DatabaseϿ
#
# ǡ, 桼̾
#
# ǡܺ١ȴƤƤܤäƤOK
# array[
# id, j(journal), y(year), v(vol), p(page), ab(abstract), t(title), a(author),
# t_jp(title_jp), j_jp(journal_jp), a_jp(author_jp),
# ]
#
# : id number
#------------------------------------------------------------

function DB($data, $user){
		include "conn.php";

		$day = getdate();
		$date = $day["year"] ."-". $day["mon"] ."-". $day["mday"];

		foreach($data as $key => $value){
			$data[$key] = str_replace("'", "\'", $data[$key]);
			$data[$key] = str_replace("\"", "&#34;", $data[$key]);
		}

		# Journal
		$sql = "SELECT Journal FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) == 0){
			$sql = "INSERT INTO ".$T_JOURNAL." VALUES('','".$data[j]."','','','0','','','','')";
			$res = mysql_query($sql, $conn);
		}
		$sql = "SELECT id FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$jid = $row["id"];

		# Author
		$Author = explode(", ",$data[a]);
		$aid = "";
		for($i=0; $i<count($Author); $i++){
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) == 0){
				$sql = "INSERT INTO ".$T_AUTHOR." VALUES('','".$Author[$i]."','','')";
				$res = mysql_query($sql, $conn);
			}
			$sql = "SELECT id FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$aid.="[".$row["id"]."],";
		}

		# Pmid	
		$sql = "INSERT INTO ".$T_ID." VALUES(";
		$sql.= "'','".$data[id]."','".$jid."','".$data[y]."','".$data[v]."','".$data[p]."',";
		$sql.= "'".$aid."','".$data[t]."','".$data[ab]."','".$user."','".$date."',";
		$sql.= "'','','".$data[t_jp]."','".$data[a_jp]."','".$data[c_t1].
			   "','','','','','')";
		$res = mysql_query($sql, $conn);

		return mysql_insert_id($conn);
}


function MOD_DB($id, $data){
		
		include "conn.php";

		foreach($data as $key => $value){
			$data[$key] = str_replace("'", "\'", $data[$key]);
			$data[$key] = str_replace("\"", "&#34;", $data[$key]);
		}

		# Journal
		$sql = "SELECT id FROM ".$T_JOURNAL." WHERE Journal='".$data[j]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$jid = $row["id"];

		# Author
		$Author = explode(", ",$data[a]);
		$aid = "";
		for($i=0; $i<count($Author); $i++){
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) == 0){
				$sql = "INSERT INTO ".$T_AUTHOR." VALUES('','".$Author[$i]."','','')";
				$res = mysql_query($sql, $conn);
			}
			$sql = "SELECT id FROM ".$T_AUTHOR." WHERE Author='".$Author[$i]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$aid.="[".$row["id"]."],";
		}
		
		# Pmid
		$sql = "UPDATE  ".$T_ID." SET ";
		$sql.= "Journal='".$jid."', Year='".$data[y]."', Volume='".$data[v]."',";
		$sql.= "Page='".$data[p]."', Author='".$aid."', Title='".$data[t]."',";
		$sql.= "Abstract='".$data[ab]."', Title_JP='".$data[t_jp].
			   "', Author_JP='".$data[a_jp]."', Custom_t1='".$data[c_t1]."' ";
		$sql.="WHERE id=$id";
		$res = mysql_query($sql, $conn);

		return mysql_insert_id($conn);
}


#-----------------------------------------------------------
# JournalDatabaseϿ, ѹ
#
# ǡ
#
# ǡܺ١ȴƤƤܤäƤOK
# array[
# j(journal), j_jp(journal_jp), j_url(journal_url), bk(book flg), act(active flg)
# e(editor), pub(publisher)
# ]
#
# : id number
#------------------------------------------------------------

function REG_JOURNAL($data){
	include "conn.php";

	foreach($data as $key => $value){
		$data[$key] = str_replace("'", "\'", $data[$key]);
		$data[$key] = str_replace("\"", "&#34;", $data[$key]);
	}
	
	$sql = "INSERT INTO ".$T_JOURNAL." VALUES(";
	$sql.= "'','".$data[j]."','".$data[j_jp]."','".$data[j_url]."','".$data[bk]."','".$data[e]."','".$data[pub]."','','')";
	$res = mysql_query($sql, $conn);
	return mysql_insert_id($conn);		
}

function EDIT_JOURNAL($data){
	include "conn.php";

	foreach($data as $key => $value){
		$data[$key] = str_replace("'", "\'", $data[$key]);
		$data[$key] = str_replace("\"", "&#34;", $data[$key]);
	}

	$sql = "UPDATE ".$T_JOURNAL." SET Journal='".$data[j]."',Journal_JP='".$data[j_jp]."',";
	$sql.="URL='".$data[j_url]."',Book='".$data[bk]."',Editor='".$data[e]."',";
	$sql.="Publisher='".$data[pub]."'";
	$sql.=" WHERE id='".$data[id]."'";
	$res = mysql_query($sql, $conn);
	return mysql_insert_id($conn);		
}
?>
